---
name: Bug report
about: Regular ol' bugs.
title: ''
labels: [ "bug" ]
assignees: marzer

---

<!--
    Replace the HTML comments below with the requested information.
    Please don't delete this template and roll your own!

    Thanks for contributing!
-->



## Environment
**toml++ version and/or commit hash:**  
<!--
    If you're using the single-header version of the library, the version number is right at the top of the file.
    Otherwise you can find it by opening toml++/impl/version.h; it'll be represented by three defines -
    TOML_LIB_MAJOR, TOML_LIB_MINOR and TOML_LIB_PATCH.
    
    If you're not using any particular release and are instead just living large at HEAD of master, the commit hash
    would be super helpful too, though it's not critical.
    
-->


**Compiler:**  
<!--
    The compiler & version, e.g. "Clang 9"
-->



**C++ standard mode:**  
<!--
    The C++ standard level you were targeting, e.g. 17, 20, 'latest'
-->



**Target arch:**  
<!--
    The architecture you were targeting, e.g. x86, x64, ARM
-->



**Library configuration overrides:**  
<!--
    If you've explicitly set any of the library configuration macros,
    list them here (e.g. TOML_EXCEPTIONS=0, TOML_ENABLE_UNRELEASED_FEATURES=1, etc.)
-->



**Relevant compilation flags:**  
<!--
    Any relevant compilation flags that might help me reproduce your issue exactly (e.g. -fno-exceptions).
-->



## Describe the bug
<!--
    A clear and concise description of the bug goes here.
-->



## Steps to reproduce (or a small repro code sample)
<!--
    As above. If you feel that the information you've already given covers it sufficiently and you don't
    need this section, you can delete it.
-->



## Additional information
<!--
    Any post-scripts, addendums, or additional pieces of context, as necessary.
-->
